==> openshift-model-config-6.6.0-sources.jar: io/fabric8/openshift/api/model/config/v1/RegistryLocationFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RegistryLocationFluentImpl<A extends RegistryLocationFluent<A>> extends BaseFluent<A> implements RegistryLocationFluent<A>{
  public RegistryLocationFluentImpl() {
  }
  public RegistryLocationFluentImpl(RegistryLocation instance) {
    this.withDomainName(instance.getDomainName()); 
    this.withInsecure(instance.getInsecure()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String domainName;
  private Boolean insecure;
  private Map<String,Object> additionalProperties;
  public String getDomainName() {
    return this.domainName;
  }
  public A withDomainName(String domainName) {
    this.domainName=domainName; return (A) this;
  }
  public Boolean hasDomainName() {
    return this.domainName != null;
  }
  public Boolean getInsecure() {
    return this.insecure;
  }
  public A withInsecure(Boolean insecure) {
    this.insecure=insecure; return (A) this;
  }
  public Boolean hasInsecure() {
    return this.insecure != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RegistryLocationFluentImpl that = (RegistryLocationFluentImpl) o;
    if (domainName != null ? !domainName.equals(that.domainName) :that.domainName != null) return false;
    if (insecure != null ? !insecure.equals(that.insecure) :that.insecure != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(domainName,  insecure,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (domainName != null) { sb.append("domainName:"); sb.append(domainName + ","); }
    if (insecure != null) { sb.append("insecure:"); sb.append(insecure + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withInsecure() {
    return withInsecure(true);
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/RegistryLocationFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RegistryLocationFluentImpl<A extends RegistryLocationFluent<A>> extends BaseFluent<A> implements RegistryLocationFluent<A>{
  public RegistryLocationFluentImpl() {
  }
  public RegistryLocationFluentImpl(RegistryLocation instance) {
    if (instance != null) {
      this.withDomainName(instance.getDomainName());
      this.withInsecure(instance.getInsecure());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String domainName;
  private Boolean insecure;
  private Map<String,Object> additionalProperties;
  public String getDomainName() {
    return this.domainName;
  }
  public A withDomainName(String domainName) {
    this.domainName=domainName; return (A) this;
  }
  public Boolean hasDomainName() {
    return this.domainName != null;
  }
  public Boolean getInsecure() {
    return this.insecure;
  }
  public A withInsecure(Boolean insecure) {
    this.insecure=insecure; return (A) this;
  }
  public Boolean hasInsecure() {
    return this.insecure != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RegistryLocationFluentImpl that = (RegistryLocationFluentImpl) o;
    if (!java.util.Objects.equals(domainName, that.domainName)) return false;

    if (!java.util.Objects.equals(insecure, that.insecure)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(domainName,  insecure,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (domainName != null) { sb.append("domainName:"); sb.append(domainName + ","); }
    if (insecure != null) { sb.append("insecure:"); sb.append(insecure + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withInsecure() {
    return withInsecure(true);
  }
  
}
